
import os
import datetime


class Xymon(object):

	clear = 4
	green = 1
	purple = 2
	yellow = 4
	red = 3

	""" Xymon monitoring object """
	def __init__(self,
		test='testname',
		color='green',
		hostname='localhost',
		text= " ",
		title='Some Test',
		ttl='60',
		my_type='status',
		dont_moan=1,
		debug=0,
		*args,
		**kwargs
		):

		super(Xymon, self).__init__()
		self.test = str(test)
		self.color = color
		self.hostname = hostname
		self.text = text
		self.title = title
		self.ttl = ttl
		self.my_type = my_type
		self.dont_moan = dont_moan
		self.debug = debug
		for key, value in kwargs.iteritems():
			print "%s = %s" % (key, value)

		self.XYMON = os.environ.get('XYMON')
		self.XYMSRV = os.environ.get('XYMSRV')

		if self.XYMON == None:
			self.XYMON = os.environ.get('BB')
		if self.XYMSRV == None:
			self.XYMSRV = os.environ.get('BBDISP')

		if self.XYMON == None:
			self.XYMON = "/opt/xymon/server/bin/bb"
			self.debug = 1
		if self.XYMSRV == None:
			# self.XYMSRV = self.hostname
			self.XYMSRV = "localhost"

	def send(self, *args, **kwargs):
		self.report = self.my_type + " " + self.hostname + "." + self.test
		self.msg = self.report  + " " + self.text
		command = str(self.XYMON) + " " + str(self.XYMSRV) + " " + str(self.msg)
		if self.debug :
			print self.print_debug()
			print command
		else:
			os.system(command)
		result = 1
		return result

	def add_color(self, *args, **kwargs):
		result = 1
		return result

	def color_print(self, *args, **kwargs):
		result = 1
		return result

	def color_line(self, *args, **kwargs):

		result = 1
		return result

	def print_line(self, *args, **kwargs):
		self.text += '\n'
		for s in args:
			self.text += str(s) + ""
		pass

	def print_debug(self, *args, **kwargs):

		print "TEST : " + self.test
		print "COLOR : " + self.color
		print "HOSTNAME : " + self.hostname
		print "TEXT : " + self.text
		print "TITLE : " + self.title
		print "TTL : " + self.ttl
		print "MY_TYPE : " + self.my_type
		for i in args:
			print i
		for key, value in kwargs.iteritems():
			print "%s : %s" % (key, value)
		result = 1
		return result




#!/usr/bin/python
# -*- coding: utf-8 -*-

from Xymon import Xymon

xymon = Xymon(debug=1)

xymon.print_line("GREEN ADDITIONAL TEXT COLORED")
xymon.print_line("ADDITIONAL TEXT")

# xymon.print_it()
xymon.send()


xymon_data = Xymon(my_type="data")
xymon.print_line("GREEN ADDITIONAL TEXT COLORED")




from setuptools import setup, find_packages  # Always prefer setuptools over distutils
from codecs import open  # To use a consistent encoding
from os import path

def read(*paths):
    """Build a file path from *paths* and return the contents."""
    with open(os.path.join(*paths), 'r') as f:
        return f.read()

here = path.abspath(path.dirname(__file__))

# Get the long description from the relevant file
with open(path.join(here, 'DESCRIPTION.rst'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='Xymon_Class',

    # Versions should comply with PEP440.  For a discussion on single-sourcing
    # the version across setup.py and the project code, see
    # http://packaging.python.org/en/latest/tutorial.html#version
    version='0.1.0',

    description='A simple Class to manipulate Xymon test script',
    long_description=long_description,

    py_modules=['Xymon_Class'],
    
    # The project's main homepage.
    url='https://github.com/erikbeauvalot/Xymon_Class',

    # Author details
    author='Erik Beauvalot',
    author_email='erik@beauvalot.com',

  )
